# `rbwr`

Rather be writing Rust

---

A small Python library providing sum types that play well with existing
typechecking PEPs and should work out-of-the-box with any good typechecker,
such as Pyright.

To see how this scheme for encoding sum types was conceived, check out [this
blog post][blog_post].

[blog_post]: http://charles.page.computer.surgery/blog/python-has-sum-types.html
